@@ -11,7 +11,7 @@ from diamond.user_classes import ImagesData, ImagePostModelSpec
 
 
 class ImagePostModelAnalysis:
-    def __init__(self, model_list: list[ImageModelResults],
+    def __init__(self, model_list,
                  images_data: ImagesData,
                  image_post_model: ImagePostModelSpec,
                  plot=True,
